# ==================================================================
# Plugins::Recommend_Link - Auto Generated Install Module
#
#   Plugins::Recommend_Link
#   Author  : Paul Wilson
#   Version : 1.0.0
#   Updated : Sun Mar 24 10:54:29 2002
#
# ==================================================================
#

package Plugins::Recommend_Link;
# ==================================================================
    use strict;
    use vars  qw/$VERSION $DEBUG $NAME $META/;
    use GT::Base;
    use GT::Plugins qw/STOP CONTINUE/;
    use Links qw/$CFG $IN $DB/;

    $VERSION = '1.0.0';
    $DEBUG   = 0;
    $NAME    = 'Recommend_Link';
# Inhert from base class for debug and error methods
    @Plugins::Recommend_Link::ISA = qw(GT::Base);

    $META = {
    'prog_ver' => '2.1.1',
    'url' => 'http://www.wiredon.net/',
    'license' => 'Freeware',
    'description' => 'This plugin let\'s you recommend a link to other people, it was created due to all the problems experienced by users with Recommend_It.',
    'author' => 'Paul Wilson',
    'version' => '1.0.0'
};


sub pre_install {
# -------------------------------------------------------------------
# This function displays an HTML formatted message that will display
# to the user any instructions/information before they install
# the plugin.
#
    my $inst_msg = 'Please continure if you wish to install the Recommend_Link plugin.';
    my $warn     = '<br><br>If this plugin has been installed before you will have an existing "RecTrack" column. 
                    Should the installer drop and re-create this column or leave it alone?<br><br>
                    <input type="radio" name="re" value="1"> Yes, drop and re-create.<br>
                    <input type="radio" name="re" value="2"> No, leave it alone.<br>
                    <input type="radio" name="re" value="3" checked> Create a new column.';

    if (-e "$CFG->{admin_root_path}/templates/$CFG->{build_default_tpl}/rec_link.html") {
        $warn .= '<br><br>Some Recommend_Link templates were found. Should the installer overwrite them?<br><br>
                  <input type="radio" name="write" value="1"> Yes, overwrite them.<br>
                  <input type="radio" name="write" value="2"> No, leave them.';
    }

    return $inst_msg . $warn;
}

sub pre_uninstall {
# -------------------------------------------------------------------
# This function displays an HTML formatted message that will display
# to the user any instructions/information before they remove the
# plugin.
#
    my $uninst_msg = 'Please don\'t unnistall me, I did you no harm.';

    return $uninst_msg;
}

sub install {
# -------------------------------------------------------------------
# This function does the actual installation. It's first argument is
# a plugin manager which you can use to register hooks, install files,
# add menu options, etc. The second argument is a GT::Tar object which
# you can use to access any files in your plugin module.
#
# You should return an HTML formatted string that will be displayed 
# to the user.
#
# If there is an error, return undef, and set the error message in
# $Plugins::Recommend_Link::error
#
    my ($mgr, $tar) = @_;
    
    $mgr->install_menu ( 'Recommend_Link', [ ['About', 'admin.cgi?do=plugin&plugin=Recommend_Link&func=about'] ] );
    $mgr->install_menu ( 'Recommend_Link', [ ['Options', 'admin.cgi?do=page&page=plugin_manager.html&plugin_man_do=edit_installed&plugin_name=Recommend_Link'] ] );
    $mgr->install_options ( 'Recommend_Link', [ ['Subject', 'You have received a recommendation!', 'This will be used as the subject sent to recommendation receivers.', 'TEXT', [], [], '' ] ] );
    $mgr->install_options ( 'Recommend_Link', [ ['Track', '', 'Should the plugin track recommendations? (ie keep count for each link)', 'SELECT', ['Yes','No'], ['1', '0'], '' ] ] );

# Silence warnings
    $GT::Tar::error ||= '';

# Only extract templates if this is a new install or we are told to.
    if (! $IN->param('write') or $IN->param('write') == 1) {

        my ($file, $code);

# Copying rec_link.cgi to $CFG->{admin_root_path}/.. directory.
        $file = $tar->get_file ('rec_link.cgi');
        $code = $file->body_as_string;
        $code =~ s/^#![^\r\n]+/#!$CFG->{path_to_perl}/; 
        $code =~ s,use lib '',use lib '$CFG->{admin_root_path}',; 
        $code =~ s,Links::init\(\),Links::init('$CFG->{admin_root_path}'),;
        $file->body($code); 
        
# Chmod to 777 so we can write to it.
        chmod(0777, "$CFG->{admin_root_path}/../");
        $file->name("$CFG->{admin_root_path}/../rec_link.cgi");
        $file->write or return Plugins::Recommend_Link->error("Unable to extract file: '$CFG->{admin_root_path}/../rec_link.cgi' ($GT::Tar::error)", 'WARN');
        chmod(0755, "$CFG->{admin_root_path}/../");

# Copying rec_link.html to $CFG->{admin_root_path}/templates/default directory.
        $file = $tar->get_file ('rec_link.html');
        $file->name("$CFG->{admin_root_path}/templates/$CFG->{build_default_tpl}/rec_link.html");
        $file->write or return Plugins::Recommend_Link->error("Unable to extract file: '$CFG->{admin_root_path}/templates/$CFG->{build_default_tpl}/rec_link.html' ($GT::Tar::error)", 'WARN');

# Copying rec_link_success.html to $CFG->{admin_root_path}/templates/default directory.
        $file = $tar->get_file ('rec_link_success.html');
        $file->name("$CFG->{admin_root_path}/templates/$CFG->{build_default_tpl}/rec_link_success.html");
        $file->write or return Plugins::Recommend_Link->error("Unable to extract file: '$CFG->{admin_root_path}/templates/$CFG->{build_default_tpl}/rec_link_success.html' ($GT::Tar::error)", 'WARN');

# Copying email-rec.txt to $CFG->{admin_root_path}/templates/default directory.
        $file = $tar->get_file ('email-rec.txt');
        $file->name("$CFG->{admin_root_path}/templates/$CFG->{build_default_tpl}/email-rec.txt");
        $file->write or return Plugins::Recommend_Link->error("Unable to extract file: '$CFG->{admin_root_path}/templates/$CFG->{build_default_tpl}/email-rec.txt' ($GT::Tar::error)", 'WARN');
     }

# Create the RecTrack column if param re == 3
    if ($IN->param('re') == 3) {
        my $editor = $DB->editor('Links');
        $editor->add_col('RecTrack',
                 {
                       size      => 20, 
                       type      => 'int',
                       view_size => 20, 
                       nice_name => "RecTrack", 
                       regex     => '^\d+$',
                       default   => 0
                 }
       ) or return Plugins::Recommend_Link->error("Unable to create RecTrack col: $GT::SQL::error");
       $DB->table('Links')->update( { RecTrack => 0 } );
    }
    elsif ($IN->param('re') == 1) {
        my $editor = $DB->editor('Links');
        $editor->drop_col('RecTrack') or return Plugins::Recommend_Link->error("Unable to drop RecTrack col: $GT::SQL::error");;
        $editor->add_col('RecTrack',
                 {
                       size      => 20, 
                       type      => 'int',
                       view_size => 20, 
                       nice_name => "RecTrack", 
                       regex     => '^\d+$' 
                 }
       ) or return Plugins::Recommend_Link->error("Unable to create RecTrack col: $GT::SQL::error");;
       $DB->table('Links')->update( { RecTrack => 0 } );  
    }
    
    return "The plugin has been successfully installed!";
}

sub uninstall {
# -------------------------------------------------------------------
# This function removes the plugin. It's first argument is
# also a plugin manager which you can use to register hooks, install files,
# add menu options, etc. You should return an HTML formatted string
# that will be displayed to the user.
#
# If there is an error, return undef, and set the error message in
# $Plugins::Recommend_Link::error
#
    my $mgr = shift;
    
    $mgr->uninstall_menu ( 'Recommend_Link', [ ['About', 'admin.cgi?do=plugin&plugin=Recommend_Link&func=about'] ] );
    $mgr->uninstall_menu ( 'Recommend_Link', [ ['Options', 'admin.cgi?do=page&page=plugin_manager.html&plugin_man_do=edit_installed&plugin_name=Recommend_Link'] ] );
    $mgr->uninstall_options ( 'Recommend_Link', [ ['Subject', 'You have received a recommendation!', 'This will be used as the subject sent to recommendation receivers.', 'TEXT', [], [], '' ] ] );
    $mgr->uninstall_options ( 'Recommend_Link', [ ['Track', '', 'Should the plugin track recommendations? (ie keep count for each link)', 'SELECT', ['Yes','No'], ['1', '0'], '' ] ] );
    
    return "The plugin has been successfully removed!";
}

1;
