# ==================================================================
# Plugins::Recommend_Link - Auto Generated Program Module
#
#   Plugins::Recommend_Link
#   Author  : Paul Wilson
#   Version : 1.0.0
#   Updated : Sun Mar 24 10:54:29 2002
#
# ==================================================================
#

package Plugins::Recommend_Link;
# ==================================================================

    use strict;
    use GT::Base;
    use Links::Plugins;
    use Links::SiteHTML;
    use GT::Template;
    use GT::Plugins qw/STOP CONTINUE/;
    use Links qw/$CFG $IN $DB/;

# Inherit from base class for debug and error methods
    @Plugins::Recommend_Link::ISA = qw(GT::Base);

# Your code begins here! Good Luck!


# ADMIN MENU OPTIONS
# ===================================================================

sub handle {
#--------------------------------------------------------------------
# Handle rec_link.cgi requests.

    my $to_compile = $IN->param('do');

# Code refs mean we need to turn strict refs off.
    no strict 'refs';
    defined &{"rec_link_$to_compile" } ? &{"rec_link_$to_compile"}        :
    Plugins::Recommend_Link->error("Please specify a valid do= parameter");
}

sub rec_link_show {
#--------------------------------------------------------------------
# Show the main page where people add names and emails.

    my $id  = $IN->param('id');

# If $ref is defined the record must exist.
    if (my $ref = $DB->table('Links')->select( { ID => $id } )->fetchrow_hashref) {
        print $IN->header();
        print Links::SiteHTML::display('rec_link', $ref );
    }
    else {
        return Plugins::Recommend_Link->error("Unable to find record with ID @{ [ $id || 0 ] }");
    }
}

sub rec_link_process {
#--------------------------------------------------------------------
# Process the recommendation.

    my $input  = $IN->get_hash;
    my @names  = grep { ! /^\s*$/ } $IN->param('Name');
    my @emails = grep { ! /^\s*$/ } $IN->param('Email');
    my $defe   = grep { /^\S+@\S+\.\S+$/ } @emails;
    my $defn   = grep { /\w+/ } @names;
    my $rec    = $DB->table('Links')->select( { ID => $input->{id} } )->fetchrow_hashref;
    my $from   = $input->{From};
    my $msg    = $input->{Body};
    my $opts   = Links::Plugins->get_plugin_user_cfg('Recommend_Link');
    my $error  = '';
    my $i      = 0;

    scalar keys %$rec or return Plugins::Recommend_Link->error("Please specify a link ID");

# Spew an error if nothing was filled in.
    if ($defe) {
        foreach my $email (@emails) {
           $email =~ /^\S+@\S+\.\S+$/ or $error = "<li> $email is not a valid email address.";
        }
        $defe == $defn or $error = "<li> Please make sure you enter a name for each email and vice versa.";
    }
    else { $error = "<li> Please enter at least one email and name." }
    
# Make sure the From field is ok (Body is optional).
    $error .= "<li> Your email address seems invalid." unless $from =~ /^\S+@\S+\.\S+$/;

# There was an error...doh!
    if ($error) {
        print $IN->header();
        print Links::SiteHTML::display('rec_link', { %$input, error => $error, %$rec } );
        exit 1;
    }

# Yay, send the emails.
    require GT::Mail;
    $GT::Mail::error ||= ''; # Shut up ye darn devils!
    foreach my $eml (@emails) {
        GT::Mail->send (
				smtp	 => $CFG->{db_smtp_server}, 
				sendmail => $CFG->{db_mail_path}, 
				to	 => $eml,
				from	 => $from,
				subject	 => $opts->{Subject} || 'No Subject',
				reply	 => $from,
				msg      => GT::Template->parse ( 'email-rec.txt', { %$input, %$CFG, %$rec, name => $names[$i], from => $from, msg => $msg }, { compress => 0, root => $CFG->{admin_root_path} . "/templates/$CFG->{build_default_tpl}" } ), 
				debug	 => $Links::DEBUG
	    ) or Plugins::Recommend_Link->error("Unable to send mail: $GT::Mail::error");
        $i++;
    }

# If counting hits then do so!
    $DB->table('Links')->update( { RecTrack => \'RecTrack + 1' } , { ID => $input->{id} } ) if $opts->{Track};

    print $IN->header();
    print Links::SiteHTML::display('rec_link_success', $rec );
}

sub about {
# -------------------------------------------------------------------
# Just some brief setup instructions.

    print $IN->header();
    print <<CODE;

<html>

<head>
<meta http-equiv="Content-Type" content="text/html; charset=windows-1252">
<title>Links SQL - Recommend_Link Plugin</title>
</head>

<body bgcolor="#FFFFFF">

<p><font face="Tahoma,Arial,Helvetica" size="3"><b><table border="1" cellpadding="0" cellspacing="0"><tr><td>
    <table bgColor="#ffffff" border="0" cellPadding="3" cellSpacing="3" width="500" valign="top">
      <tr>
        <td align="left" bgColor="navy"><b><font color="#ffffff" size="2" face="Tahoma,Arial,Helvetica">Recommend_Link Plugin</font></b></td>
      </tr>
      <tr>
        <td>
          <p align="center"><b><font color="#000000" size="2" face="Tahoma,Arial,Helvetica">Recommend a Link</font></b></p>
          <p><font size="2" face="Tahoma,Arial,Helvetica">This plugin lets you recommend a link to one or more friends.</font>
        
          </td>
      </tr>
    </table>
    </td></tr>
</table>
</b></font></p>


<p><font face="Tahoma,Arial,Helvetica" size="2">
    Installation of this plugin is very simple. All you need to do is add the following html into your link.html template.<br><br>
    &lt;a href="&lt;%db_cgi_url%>/rec_link.cgi?do=show&id=&lt;%ID%>">Recommend&lt;/a>
    <br><br>
This plugin is freeware an was written by Paul Wilson (pwilson\@wiredon.net).
</font>
</p>
</body>
</html>
CODE

}

# Always end with a 1.
1;
